@@ -1,37 +1,25 @@
-/***************************************************************************
-                          sieve.h  -  description
-                             -------------------
-    begin                : Thu Dec 20 18:47:08 EST 2001
-    copyright            : (C) 2001 by Hamish Rodda
-    email                : meddie@yoyo.cc.monash.edu.au
- ***************************************************************************/
+/*
+    sieve.h
+
+    SPDX-FileCopyrightText: 2001 Hamish Rodda <meddie@yoyo.cc.monash.edu.au>
+
+    SPDX-License-Identifier: GPL-2.0-only
+*/
 
-/***************************************************************************
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License version 2 as     *
- *   published by the Free Software Foundation.                            *
- *                                                                         *
- ***************************************************************************/
 #ifndef SIEVE_H
 #define SIEVE_H
 
-#include <kio/tcpslavebase.h>
 #include <kio/authinfo.h>
+#include <kio/tcpslavebase.h>
 
-#include <QString>
 #include <QByteArray>
+#include <QString>
 #include <QStringList>
 
 class kio_sieveResponse
 {
 public:
-    enum responses {
-        NONE,
-        KEY_VAL_PAIR,
-        ACTION,
-        QUANTITY
-    };
+    enum responses { NONE, KEY_VAL_PAIR, ACTION, QUANTITY };
 
     kio_sieveResponse();
 
@@ -62,16 +50,8 @@ protected:
 class kio_sieveProtocol : public KIO::TCPSlaveBase
 {
 public:
-    enum connectionModes {
-        NORMAL,
-        CONNECTION_ORIENTED
-    };
-    enum Results {
-        OK,
-        NO,
-        BYE,
-        OTHER
-    };
+    enum connectionModes { NORMAL, CONNECTION_ORIENTED };
+    enum Results { OK, NO, BYE, OTHER };
 
     kio_sieveProtocol(const QByteArray &pool_socket, const QByteArray &app_socket);
     ~kio_sieveProtocol() override;
@@ -88,7 +68,7 @@ public:
     void setHost(const QString &host, quint16 port, const QString &user, const QString &pass) override;
     void openConnection() override;
     void closeConnection() override;
-    //virtual void slave_status();
+    // virtual void slave_status();
 
     /**
      * Special commands supported by this slave:
@@ -112,7 +92,7 @@ protected:
     int operationResult();
 
     bool parseCapabilities(bool requestCapabilities = false);
-    bool saslInteract(void *in, KIO::AuthInfo & ai);
+    bool saslInteract(void *in, KIO::AuthInfo &ai);
 
     // IOSlave global data
     uint m_connMode;
@@ -121,7 +101,7 @@ protected:
     QStringList m_sasl_caps;
     bool m_supportsTLS;
 
-    // Global server respose class
+    // Global server response class
     kio_sieveResponse r;
 
     // connection details
