@@ -11,7 +11,8 @@
 #ifndef KSIEVE_IMPL_UTF8VALIDATOR_H
 #define KSIEVE_IMPL_UTF8VALIDATOR_H
 
-namespace KSieve {
+namespace KSieve
+{
 extern bool isValidUtf8(const char *s, unsigned int len);
 } // namespace KSieve
 
