@@ -15,13 +15,14 @@ class QString;
 
 namespace KSieve
 {
-
 class Error;
 
 class ScriptBuilder
 {
 public:
-    virtual ~ScriptBuilder() {}
+    virtual ~ScriptBuilder()
+    {
+    }
 
     virtual void taggedArgument(const QString &tag) = 0;
     virtual void stringArgument(const QString &string, bool multiLine, const QString &embeddedHashComment) = 0;
