@@ -1,20 +1,20 @@
 /*
-   SPDX-FileCopyrightText: 2013-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2013-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "autocreatescriptdialog.h"
-#include "sievescriptlistbox.h"
-#include "sieveconditionwidgetlister.h"
 #include "sieveactionwidgetlister.h"
+#include "sieveconditionwidgetlister.h"
 #include "sieveeditorgraphicalmodewidget.h"
+#include "sievescriptlistbox.h"
 
+#include <KConfigGroup>
 #include <KLocalizedString>
 #include <KSharedConfig>
-#include <QKeyEvent>
 #include <QDialogButtonBox>
-#include <KConfigGroup>
+#include <QKeyEvent>
 #include <QPushButton>
 #include <QVBoxLayout>
 
@@ -25,8 +25,8 @@ AutoCreateScriptDialog::AutoCreateScriptDialog(QWidget *parent)
     , mEditor(new SieveEditorGraphicalModeWidget(this))
 {
     setWindowTitle(i18nc("@title:window", "Create Sieve Filter"));
-    auto *mainLayout = new QVBoxLayout(this);
-    QDialogButtonBox *buttonBox = new QDialogButtonBox(QDialogButtonBox::Ok | QDialogButtonBox::Cancel, this);
+    auto mainLayout = new QVBoxLayout(this);
+    auto buttonBox = new QDialogButtonBox(QDialogButtonBox::Ok | QDialogButtonBox::Cancel, this);
     QPushButton *okButton = buttonBox->button(QDialogButtonBox::Ok);
     okButton->setDefault(true);
     okButton->setShortcut(Qt::CTRL | Qt::Key_Return);
@@ -87,7 +87,7 @@ bool AutoCreateScriptDialog::event(QEvent *e)
 {
     const bool shortCutOverride = (e->type() == QEvent::ShortcutOverride);
     if (shortCutOverride || e->type() == QEvent::KeyPress) {
-        auto *kev = static_cast<QKeyEvent * >(e);
+        auto kev = static_cast<QKeyEvent *>(e);
         if (kev->key() == Qt::Key_Escape) {
             e->ignore();
             return true;
