@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2013-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2013-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -7,7 +7,8 @@
 #define SIEVEACTIONADDHEADER_H
 
 #include "sieveactionabstracteditheader.h"
-namespace KSieveUi {
+namespace KSieveUi
+{
 class SieveActionAddHeader : public SieveActionAbstractEditHeader
 {
     Q_OBJECT
