@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2013-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2013-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -8,7 +8,8 @@
 
 #include "sieveaction.h"
 #include <autocreatescripts/sieveglobalvariablewidget.h>
-namespace KSieveUi {
+namespace KSieveUi
+{
 class SieveActionSetVariable : public SieveAction
 {
     Q_OBJECT
@@ -23,6 +24,7 @@ public:
     Q_REQUIRED_RESULT QWidget *createParamWidget(QWidget *parent) const override;
     Q_REQUIRED_RESULT QUrl href() const override;
     void setLocalVariable(QWidget *w, const SieveGlobalVariableActionWidget::VariableElement &var);
+
 private:
     bool mHasRegexCapability = false;
 };
