@@ -1,15 +1,16 @@
 /*
-   SPDX-FileCopyrightText: 2013-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2013-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 #ifndef ADDRESSLINEEDIT_H
 #define ADDRESSLINEEDIT_H
 
-#include <QLineEdit>
-#include <KSieveUi/AbstractSelectEmailLineEdit>
 #include "ksieveui_private_export.h"
-namespace KSieveUi {
+#include <KSieveUi/AbstractSelectEmailLineEdit>
+#include <QLineEdit>
+namespace KSieveUi
+{
 class KSIEVEUI_TESTS_EXPORT AddressLineEdit : public AbstractSelectEmailLineEdit
 {
     Q_OBJECT
