@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2013-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2013-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -9,13 +9,14 @@
 
 #include <QWidget>
 class QComboBox;
-namespace KSieveUi {
+namespace KSieveUi
+{
 class SelectRelationalMatchType : public QWidget
 {
     Q_OBJECT
 public:
     explicit SelectRelationalMatchType(QWidget *parent = nullptr);
-    ~SelectRelationalMatchType();
+    ~SelectRelationalMatchType() override;
 
     Q_REQUIRED_RESULT QString code() const;
     void setCode(const QString &type, const QString &comparatorStr, const QString &name, QString &error);
