@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2013-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2013-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -7,22 +7,23 @@
 #include "sieveconditionwidgetlister.h"
 #include "autocreatescriptdialog.h"
 #include "autocreatescriptutil_p.h"
-#include "libksieve_debug.h"
 #include "commonwidgets/sievehelpbutton.h"
-#include "sieveeditorgraphicalmodewidget.h"
-#include "sieveconditions/sieveconditionlist.h"
+#include "libksieve_debug.h"
 #include "sieveconditions/sievecondition.h"
+#include "sieveconditions/sieveconditionlist.h"
+#include "sieveeditorgraphicalmodewidget.h"
 
-#include <QPushButton>
 #include <KLocalizedString>
-#include <QIcon>
 #include <QComboBox>
+#include <QIcon>
 #include <QPointer>
+#include <QPushButton>
+#include <QUrl>
 
+#include "sievescriptdescriptiondialog.h"
 #include <QGridLayout>
 #include <QLabel>
 #include <QWhatsThis>
-#include "sievescriptdescriptiondialog.h"
 
 using namespace KSieveUi;
 
@@ -57,7 +58,7 @@ void SieveConditionWidget::setFilterCondition(QWidget *widget)
 
 void SieveConditionWidget::generatedScript(QString &script, QStringList &required, bool inForEveryPartLoop)
 {
-    Q_UNUSED(inForEveryPartLoop);
+    Q_UNUSED(inForEveryPartLoop)
     const int index = mComboBox->currentIndex();
     if (index != mComboBox->count() - 1) {
         KSieveUi::SieveCondition *widgetCondition = mConditionList.at(mComboBox->currentIndex());
@@ -94,7 +95,7 @@ void SieveConditionWidget::initWidget()
                 // add (i18n-ized) name to combo box
                 mComboBox->addItem((*it)->label(), (*it)->name());
             } else {
-                delete(*it);
+                delete (*it);
             }
         } else {
             // append to the list of actions:
@@ -271,7 +272,7 @@ void SieveConditionWidgetLister::updateAddRemoveButton()
     QList<QWidget *>::ConstIterator wIt = widgetList.constBegin();
     QList<QWidget *>::ConstIterator wEnd = widgetList.constEnd();
     for (; wIt != wEnd; ++wIt) {
-        auto *w = qobject_cast<SieveConditionWidget *>(*wIt);
+        auto w = qobject_cast<SieveConditionWidget *>(*wIt);
         w->updateAddRemoveButton(addButtonEnabled, removeButtonEnabled);
     }
 }
@@ -286,7 +287,7 @@ void SieveConditionWidgetLister::reconnectWidget(SieveConditionWidget *w)
 void SieveConditionWidgetLister::clearWidget(QWidget *aWidget)
 {
     if (aWidget) {
-        auto *widget = static_cast<SieveConditionWidget *>(aWidget);
+        auto widget = static_cast<SieveConditionWidget *>(aWidget);
         widget->clear();
     }
     Q_EMIT valueChanged();
@@ -294,7 +295,7 @@ void SieveConditionWidgetLister::clearWidget(QWidget *aWidget)
 
 QWidget *SieveConditionWidgetLister::createWidget(QWidget *parent)
 {
-    auto *w = new SieveConditionWidget(mSieveGraphicalModeWidget, parent);
+    auto w = new SieveConditionWidget(mSieveGraphicalModeWidget, parent);
     reconnectWidget(w);
     return w;
 }
@@ -307,7 +308,7 @@ void SieveConditionWidgetLister::generatedScript(QString &script, int &numberOfC
     bool wasFirst = true;
     for (; wIt != wEnd; ++wIt) {
         QString condition;
-        auto *w = qobject_cast<SieveConditionWidget *>(*wIt);
+        auto w = qobject_cast<SieveConditionWidget *>(*wIt);
         w->generatedScript(condition, requireModules, inForEveryPartLoop);
         if (!condition.isEmpty()) {
             if (!wasFirst) {
@@ -335,7 +336,7 @@ void SieveConditionWidgetLister::loadTest(QXmlStreamReader &element, bool notCon
     }
     if (element.attributes().hasAttribute(QLatin1String("name"))) {
         const QString conditionName = element.attributes().value(QLatin1String("name")).toString();
-        auto *w = qobject_cast<SieveConditionWidget *>(widgets().constLast());
+        auto w = qobject_cast<SieveConditionWidget *>(widgets().constLast());
         w->setCondition(conditionName, element, notCondition, error);
     }
     if (notCondition) {
@@ -365,7 +366,7 @@ void SieveConditionWidgetLister::loadScript(QXmlStreamReader &element, bool uniq
                             } else {
                                 addWidgetAfterThisWidget(widgets().constLast());
                             }
-                            auto *w = qobject_cast<SieveConditionWidget *>(widgets().constLast());
+                            auto w = qobject_cast<SieveConditionWidget *>(widgets().constLast());
                             if (conditionName == QLatin1String("not")) {
                                 notCondition = true;
                                 element.readNextStartElement();
@@ -381,12 +382,12 @@ void SieveConditionWidgetLister::loadScript(QXmlStreamReader &element, bool uniq
                         }
                     } else if (testTagName == QLatin1String("crlf")) {
                         element.skipCurrentElement();
-                        //nothing
+                        // nothing
                     } else if (testTagName == QLatin1String("comment")) {
                         qDebug() << "Need to implement comment here ";
                         element.skipCurrentElement();
-                        //nothing
-                        //implement in the future ?
+                        // nothing
+                        // implement in the future ?
                     } else {
                         qCDebug(LIBKSIEVE_LOG) << " SieveConditionWidgetLister::loadScript unknown condition tag: " << testTagName;
                     }
