@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2013-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2013-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -9,16 +9,18 @@
 
 #include <QDialog>
 
-namespace KPIMTextEdit {
+namespace KPIMTextEdit
+{
 class PlainTextEditorWidget;
 }
-namespace KSieveUi {
+namespace KSieveUi
+{
 class SieveScriptDescriptionDialog : public QDialog
 {
     Q_OBJECT
 public:
     explicit SieveScriptDescriptionDialog(QWidget *parent = nullptr);
-    ~SieveScriptDescriptionDialog();
+    ~SieveScriptDescriptionDialog() override;
 
     void setDescription(const QString &desc);
     Q_REQUIRED_RESULT QString description() const;
