@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2013-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2013-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -7,11 +7,12 @@
 #ifndef SIEVESCRIPTPAGE_H
 #define SIEVESCRIPTPAGE_H
 
-#include <QWidget>
-#include "sievescriptblockwidget.h"
 #include "ksieveui_private_export.h"
+#include "sievescriptblockwidget.h"
+#include <QWidget>
 
-namespace KSieveUi {
+namespace KSieveUi
+{
 class SieveScriptBlockWidget;
 class SieveScriptTabWidget;
 class SieveIncludeWidget;
@@ -23,7 +24,7 @@ class KSIEVEUI_TESTS_EXPORT SieveScriptPage : public QWidget
     Q_OBJECT
 public:
     explicit SieveScriptPage(SieveEditorGraphicalModeWidget *sieveEditorGraphicalWidget, QWidget *parent = nullptr);
-    ~SieveScriptPage();
+    ~SieveScriptPage() override;
 
     void generatedScript(QString &script, QStringList &required);
 
