@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2013-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2013-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -8,16 +8,18 @@
 #define SIEVESCRIPTPARSINGERRORDIALOG_H
 #include "ksieveui_private_export.h"
 #include <QDialog>
-namespace KPIMTextEdit {
+namespace KPIMTextEdit
+{
 class RichTextEditorWidget;
 }
-namespace KSieveUi {
+namespace KSieveUi
+{
 class KSIEVEUI_TESTS_EXPORT SieveScriptParsingErrorDialog : public QDialog
 {
     Q_OBJECT
 public:
     explicit SieveScriptParsingErrorDialog(QWidget *parent = nullptr);
-    ~SieveScriptParsingErrorDialog();
+    ~SieveScriptParsingErrorDialog() override;
 
     void setError(QString script, QString);
 
