@@ -1,45 +1,45 @@
-/* SPDX-FileCopyrightText: 2013-2020 Laurent Montel <montel@kde.org>
+/* SPDX-FileCopyrightText: 2013-2021 Laurent Montel <montel@kde.org>
  *
  * SPDX-License-Identifier: LGPL-2.0-or-later
  */
 
 #include "sieveeditortextmodewidget.h"
-#include "templates/sievetemplatewidget.h"
 #include "autocreatescripts/autocreatescriptdialog.h"
-#include "editor/sievetextedit.h"
-#include "editor/warningwidget/sieveeditorwarning.h"
-#include "editor/warningwidget/sieveeditorparsingmissingfeaturewarning.h"
 #include "editor/sieveeditortabwidget.h"
+#include "editor/sievetextedit.h"
+#include "editor/warningwidget/sieveeditorparsingmissingfeaturewarning.h"
+#include "editor/warningwidget/sieveeditorwarning.h"
 #include "sievescriptdebugger/sievescriptdebuggerdialog.h"
+#include "templates/sievetemplatewidget.h"
 
-#include "scriptsparsing/xmlprintingscriptbuilder.h"
 #include "scriptsparsing/parsingresultdialog.h"
+#include "scriptsparsing/xmlprintingscriptbuilder.h"
 
-#include <KPIMTextEdit/PlainTextEditFindBar>
-#include <KPIMTextEdit/PlainTextEditorWidget>
-#include <KPIMTextEdit/TextToSpeechWidget>
-#include <KPIMTextEdit/TextGotoLineWidget>
 #include "KSplitterCollapserButton"
 #include "webengine/sieveeditorhelphtmlwidget.h"
+#include <KPIMTextEdit/PlainTextEditFindBar>
+#include <KPIMTextEdit/PlainTextEditorWidget>
 #include <KPIMTextEdit/SlideContainer>
+#include <KPIMTextEdit/TextGotoLineWidget>
+#include <KPIMTextEdit/TextToSpeechWidget>
 
-#include <ksieve/parser.h>
 #include <ksieve/error.h>
+#include <ksieve/parser.h>
 #include <ksieve/scriptbuilder.h>
 
-#include <KLocalizedString>
-#include <KSharedConfig>
 #include <KConfigGroup>
+#include <KLocalizedString>
 #include <KMessageBox>
+#include <KSharedConfig>
 
-#include <QSplitter>
-#include <QShortcut>
-#include <QPointer>
-#include <QPushButton>
-#include <QVBoxLayout>
-#include <QPrinter>
-#include <QPrintDialog>
 #include <PimCommon/KPimPrintPreviewDialog>
+#include <QPointer>
+#include <QPrintDialog>
+#include <QPrinter>
+#include <QPushButton>
+#include <QShortcut>
+#include <QSplitter>
+#include <QVBoxLayout>
 
 #include <errno.h>
 #include <memory>
@@ -49,7 +49,7 @@ using namespace KSieveUi;
 SieveEditorTextModeWidget::SieveEditorTextModeWidget(QWidget *parent)
     : SieveEditorAbstractWidget(parent)
 {
-    auto *lay = new QVBoxLayout(this);
+    auto lay = new QVBoxLayout(this);
     lay->setContentsMargins({});
 
     mMainSplitter = new QSplitter;
@@ -61,12 +61,12 @@ SieveEditorTextModeWidget::SieveEditorTextModeWidget(QWidget *parent)
     //
     mSieveTemplateWidget = new SieveTemplateWidget(i18n("Sieve Template:"));
 
-    QWidget *textEditWidget = new QWidget;
-    auto *textEditLayout = new QVBoxLayout;
+    auto textEditWidget = new QWidget;
+    auto textEditLayout = new QVBoxLayout;
     textEditLayout->setContentsMargins({});
 
     mEditorWidget = new QWidget;
-    auto *editorWidgetLayout = new QVBoxLayout;
+    auto editorWidgetLayout = new QVBoxLayout;
     editorWidgetLayout->setContentsMargins({});
     mEditorWidget->setLayout(editorWidgetLayout);
 
@@ -198,8 +198,7 @@ void SieveEditorTextModeWidget::slotShowGoToLine()
 void SieveEditorTextModeWidget::generateXml()
 {
     const QByteArray script = mTextEdit->toPlainText().toUtf8();
-    KSieve::Parser parser(script.begin(),
-                          script.begin() + script.length());
+    KSieve::Parser parser(script.begin(), script.begin() + script.length());
     KSieveUi::XMLPrintingScriptBuilder psb(2);
     parser.setScriptBuilder(&psb);
     const bool result = parser.parse();
@@ -216,8 +215,7 @@ void SieveEditorTextModeWidget::generateXml()
 void SieveEditorTextModeWidget::slotEditRule(const QString &selectedText)
 {
     const QByteArray script = selectedText.toUtf8();
-    KSieve::Parser parser(script.begin(),
-                          script.begin() + script.length());
+    KSieve::Parser parser(script.begin(), script.begin() + script.length());
     KSieveUi::XMLPrintingScriptBuilder psb(2);
     parser.setScriptBuilder(&psb);
     const bool result = parser.parse();
@@ -227,7 +225,7 @@ void SieveEditorTextModeWidget::slotEditRule(const QString &selectedText)
         dlg->setSieveImapAccountSettings(mSieveImapAccountSettings);
         dlg->setListOfIncludeFile(mListOfIncludeFile);
         QString error;
-        //qDebug() << " psb.result()" << psb.result();
+        // qDebug() << " psb.result()" << psb.result();
         dlg->loadScript(psb.result(), error);
         if (dlg->exec()) {
             QStringList requireModules;
@@ -347,7 +345,7 @@ void SieveEditorTextModeWidget::copy()
     QWidget *w = mTabWidget->currentWidget();
     if (w == mEditorWidget) {
         mTextEdit->copy();
-    } else if (auto *page = qobject_cast<SieveEditorHelpHtmlWidget *>(w)) {
+    } else if (auto page = qobject_cast<SieveEditorHelpHtmlWidget *>(w)) {
         page->copy();
     }
 }
@@ -357,7 +355,7 @@ void SieveEditorTextModeWidget::selectAll()
     QWidget *w = mTabWidget->currentWidget();
     if (w == mEditorWidget) {
         mTextEdit->selectAll();
-    } else if (auto *page = qobject_cast<SieveEditorHelpHtmlWidget *>(w)) {
+    } else if (auto page = qobject_cast<SieveEditorHelpHtmlWidget *>(w)) {
         page->selectAll();
     }
 }
@@ -385,7 +383,7 @@ bool SieveEditorTextModeWidget::hasSelection() const
     QWidget *w = mTabWidget->currentWidget();
     if (w == mEditorWidget) {
         return mTextEdit->textCursor().hasSelection();
-    } else if (auto *page = qobject_cast<SieveEditorHelpHtmlWidget *>(w)) {
+    } else if (auto page = qobject_cast<SieveEditorHelpHtmlWidget *>(w)) {
         return page->hasSelection();
     }
     return false;
@@ -396,7 +394,7 @@ void SieveEditorTextModeWidget::zoomIn()
     QWidget *w = mTabWidget->currentWidget();
     if (w == mEditorWidget) {
         mTextEdit->zoomIn();
-    } else if (auto *page = qobject_cast<SieveEditorHelpHtmlWidget *>(w)) {
+    } else if (auto page = qobject_cast<SieveEditorHelpHtmlWidget *>(w)) {
         page->zoomIn();
     }
 }
@@ -406,7 +404,7 @@ void SieveEditorTextModeWidget::zoomOut()
     QWidget *w = mTabWidget->currentWidget();
     if (w == mEditorWidget) {
         mTextEdit->zoomOut();
-    } else if (auto *page = qobject_cast<SieveEditorHelpHtmlWidget *>(w)) {
+    } else if (auto page = qobject_cast<SieveEditorHelpHtmlWidget *>(w)) {
         page->zoomOut();
     }
 }
@@ -459,7 +457,7 @@ void SieveEditorTextModeWidget::zoomReset()
     QWidget *w = mTabWidget->currentWidget();
     if (w == mEditorWidget) {
         mTextEdit->slotZoomReset();
-    } else if (auto *page = qobject_cast<SieveEditorHelpHtmlWidget *>(w)) {
+    } else if (auto page = qobject_cast<SieveEditorHelpHtmlWidget *>(w)) {
         page->resetZoom();
     }
 }
@@ -475,7 +473,7 @@ void SieveEditorTextModeWidget::slotFind()
         mFindBar->showFind();
         mSliderContainer->slideIn();
         mFindBar->focusAndSetCursor();
-    } else if (auto *page = qobject_cast<SieveEditorHelpHtmlWidget *>(w)) {
+    } else if (auto page = qobject_cast<SieveEditorHelpHtmlWidget *>(w)) {
         page->find();
     }
 }
