@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2016-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2016-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -7,10 +7,10 @@
 #include "sieveeditorhelphtmlwidgettest.h"
 #include "../sieveeditorhelphtmlwidget.h"
 
-#include <QTest>
 #include "../findbar/findbarwebengineview.h"
 #include "../sieveeditorloadprogressindicator.h"
 #include "../sieveeditorwebengineview.h"
+#include <QTest>
 
 #include <KPIMTextEdit/SlideContainer>
 
@@ -29,16 +29,16 @@ void SieveEditorHelpHtmlWidgetTest::shouldHaveDefaultValue()
     w.show();
     QVERIFY(QTest::qWaitForWindowExposed(&w));
 
-    //KSieveUi::SieveEditorLoadProgressIndicator *mProgressIndicator = w.findChild<KSieveUi::SieveEditorLoadProgressIndicator *>(QStringLiteral("progressindicator"));
-    //QVERIFY(mProgressIndicator);
+    // KSieveUi::SieveEditorLoadProgressIndicator *mProgressIndicator = w.findChild<KSieveUi::SieveEditorLoadProgressIndicator
+    // *>(QStringLiteral("progressindicator")); QVERIFY(mProgressIndicator);
 
-    //KSieveUi::SieveEditorWebEngineView *mWebView = w.findChild<KSieveUi::SieveEditorWebEngineView *>(QStringLiteral("webview"));
-    //QVERIFY(mWebView);
+    // KSieveUi::SieveEditorWebEngineView *mWebView = w.findChild<KSieveUi::SieveEditorWebEngineView *>(QStringLiteral("webview"));
+    // QVERIFY(mWebView);
 
-    auto *mSliderContainer = w.findChild<KPIMTextEdit::SlideContainer *>(QStringLiteral("slidercontainer"));
+    auto mSliderContainer = w.findChild<KPIMTextEdit::SlideContainer *>(QStringLiteral("slidercontainer"));
     QVERIFY(mSliderContainer);
 
-    auto *mFindBar = w.findChild<KSieveUi::FindBarWebEngineView *>(QStringLiteral("findbar"));
+    auto mFindBar = w.findChild<KSieveUi::FindBarWebEngineView *>(QStringLiteral("findbar"));
     QVERIFY(mFindBar);
 }
 
