@@ -1,4 +1,4 @@
-/* SPDX-FileCopyrightText: 2016-2020 Laurent Montel <montel@kde.org>
+/* SPDX-FileCopyrightText: 2016-2021 Laurent Montel <montel@kde.org>
  *
  * SPDX-License-Identifier: LGPL-2.0-or-later
  */
@@ -8,10 +8,12 @@
 
 #include "findbarbase.h"
 #include "ksieveui_export.h"
+#include <memory>
 
 class QWebEngineView;
 
-namespace KSieveUi {
+namespace KSieveUi
+{
 class FindBarWebEngineViewPrivate;
 class KSIEVEUI_EXPORT FindBarWebEngineView : public FindBarBase
 {
@@ -26,7 +28,7 @@ private:
     void updateSensitivity(bool sensitivity) override;
 
 private:
-    FindBarWebEngineViewPrivate *const d;
+    std::unique_ptr<FindBarWebEngineViewPrivate> const d;
 };
 }
 
