@@ -1,24 +1,26 @@
 /*
-   SPDX-FileCopyrightText: 2013-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2013-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 #ifndef PARSINGRESULTDIALOG_H
 #define PARSINGRESULTDIALOG_H
 #include "ksieveui_private_export.h"
-#include <QDialog>
 #include <KSyntaxHighlighting/Repository>
+#include <QDialog>
 
-namespace KPIMTextEdit {
+namespace KPIMTextEdit
+{
 class PlainTextEditorWidget;
 }
-namespace KSieveUi {
+namespace KSieveUi
+{
 class KSIEVEUI_TESTS_EXPORT ParsingResultDialog : public QDialog
 {
     Q_OBJECT
 public:
     explicit ParsingResultDialog(QWidget *parent = nullptr);
-    ~ParsingResultDialog();
+    ~ParsingResultDialog() override;
 
     void setResultParsing(const QString &result);
 
