@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2013-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2013-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -14,14 +14,14 @@
 #include <KLocalizedString>
 #include <QLineEdit>
 
-#include <QVBoxLayout>
+#include <KConfigGroup>
+#include <KSharedConfig>
+#include <QDialogButtonBox>
 #include <QHBoxLayout>
 #include <QLabel>
-#include <QShortcut>
-#include <KSharedConfig>
-#include <KConfigGroup>
-#include <QDialogButtonBox>
 #include <QPushButton>
+#include <QShortcut>
+#include <QVBoxLayout>
 
 #include <editor/sievetexteditwidget.h>
 
@@ -33,7 +33,7 @@ SieveTemplateEditDialog::SieveTemplateEditDialog(QWidget *parent, bool defaultTe
     : QDialog(parent)
 {
     setWindowTitle(defaultTemplate ? i18n("Default template") : i18n("Template"));
-    auto *mainLayout = new QVBoxLayout(this);
+    auto mainLayout = new QVBoxLayout(this);
     QDialogButtonBox *buttonBox = nullptr;
     if (defaultTemplate) {
         buttonBox = new QDialogButtonBox(QDialogButtonBox::Close, this);
@@ -46,16 +46,16 @@ SieveTemplateEditDialog::SieveTemplateEditDialog(QWidget *parent, bool defaultTe
         connect(buttonBox, &QDialogButtonBox::rejected, this, &SieveTemplateEditDialog::reject);
         mOkButton->setDefault(true);
     }
-    QWidget *w = new QWidget;
+    auto w = new QWidget;
 
-    auto *vbox = new QVBoxLayout;
+    auto vbox = new QVBoxLayout;
     vbox->setContentsMargins({});
 
-    auto *hbox = new QHBoxLayout;
-    QLabel *label = new QLabel(i18n("Name:"));
+    auto hbox = new QHBoxLayout;
+    auto label = new QLabel(i18n("Name:"), this);
     hbox->addWidget(label);
 
-    mTemplateNameEdit = new QLineEdit;
+    mTemplateNameEdit = new QLineEdit(this);
     mTemplateNameEdit->setReadOnly(defaultTemplate);
     new KPIM::LineEditCatchReturnKey(mTemplateNameEdit, this);
     mTemplateNameEdit->setClearButtonEnabled(!defaultTemplate);
@@ -63,7 +63,7 @@ SieveTemplateEditDialog::SieveTemplateEditDialog(QWidget *parent, bool defaultTe
 
     vbox->addLayout(hbox);
 
-    auto *textToSpeechWidget = new KPIMTextEdit::TextToSpeechWidget(this);
+    auto textToSpeechWidget = new KPIMTextEdit::TextToSpeechWidget(this);
     vbox->addWidget(textToSpeechWidget);
 
     mTextEditWidget = new KSieveUi::SieveTextEditWidget;
@@ -72,12 +72,12 @@ SieveTemplateEditDialog::SieveTemplateEditDialog(QWidget *parent, bool defaultTe
     vbox->addWidget(mTextEditWidget);
     connect(mTextEditWidget->textEdit(), &SieveTextEdit::say, textToSpeechWidget, &KPIMTextEdit::TextToSpeechWidget::say);
 
-    auto *shortcut = new QShortcut(this);
-    shortcut->setKey(Qt::Key_F + Qt::CTRL);
+    auto shortcut = new QShortcut(this);
+    shortcut->setKey(Qt::Key_F | Qt::CTRL);
     connect(shortcut, &QShortcut::activated, mTextEditWidget, &SieveTextEditWidget::slotFind);
 
     shortcut = new QShortcut(this);
-    shortcut->setKey(Qt::Key_R + Qt::CTRL);
+    shortcut->setKey(Qt::Key_R | Qt::CTRL);
     connect(shortcut, &QShortcut::activated, mTextEditWidget, &SieveTextEditWidget::slotReplace);
 
     w->setLayout(vbox);
