@@ -1,21 +1,21 @@
 /*
-   SPDX-FileCopyrightText: 2013-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2013-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "sievetemplatewidget.h"
-#include "sievetemplateeditdialog.h"
-#include "sievedefaulttemplate.h"
-#include <PimCommon/TemplateManager>
 #include "autocreatescripts/sieveeditorgraphicalmodewidget.h"
+#include "sievedefaulttemplate.h"
+#include "sievetemplateeditdialog.h"
+#include <PimCommon/TemplateManager>
 
 #include <KLocalizedString>
 
-#include <QPointer>
 #include <QLabel>
-#include <QVBoxLayout>
 #include <QMimeData>
+#include <QPointer>
+#include <QVBoxLayout>
 
 using namespace KSieveUi;
 SieveTemplateListWidget::SieveTemplateListWidget(const QString &configName, QWidget *parent)
@@ -36,7 +36,7 @@ QMimeData *SieveTemplateListWidget::mimeData(const QList<QListWidgetItem *> item
     if (items.isEmpty()) {
         return nullptr;
     }
-    auto *mimeData = new QMimeData();
+    auto mimeData = new QMimeData();
     QListWidgetItem *item = items.first();
     QString templateStr = item->data(TemplateListWidget::Text).toString();
     if (!mCapabilities.contains(QLatin1String("imap4flags")) && templateStr.contains(QLatin1String("imap4flags"))) {
@@ -90,9 +90,9 @@ bool SieveTemplateListWidget::modifyTemplate(QString &templateName, QString &tem
 SieveTemplateWidget::SieveTemplateWidget(const QString &title, QWidget *parent)
     : QWidget(parent)
 {
-    auto *lay = new QVBoxLayout(this);
+    auto lay = new QVBoxLayout(this);
     lay->setContentsMargins({});
-    QLabel *lab = new QLabel(title, this);
+    auto lab = new QLabel(title, this);
     lay->addWidget(lab);
     mListTemplate = new SieveTemplateListWidget(QStringLiteral("sievetemplaterc"), this);
     mListTemplate->setWhatsThis(i18n("You can drag and drop element on editor to import template"));
