@@ -1,24 +1,24 @@
 /*
-   SPDX-FileCopyrightText: 2017-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2017-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "vacationmailactionwidget.h"
-#include "widgets/moveimapfolderwidget.h"
-#include "widgets/abstractselectemaillineedit.h"
 #include "autocreatescripts/autocreatescriptutil_p.h"
-#include <QStackedWidget>
-#include <QHBoxLayout>
-#include <KPluginLoader>
+#include "widgets/abstractselectemaillineedit.h"
+#include "widgets/moveimapfolderwidget.h"
 #include <KPluginFactory>
+#include <KPluginLoader>
+#include <QHBoxLayout>
+#include <QStackedWidget>
 
 using namespace KSieveUi;
 
 VacationMailActionWidget::VacationMailActionWidget(QWidget *parent)
     : QWidget(parent)
 {
-    auto *mainLayout = new QHBoxLayout(this);
+    auto mainLayout = new QHBoxLayout(this);
     mainLayout->setObjectName(QStringLiteral("mainlayout"));
     mainLayout->setContentsMargins({});
 
