@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2013-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2013-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -11,8 +11,10 @@
 
 class QDate;
 
-namespace KSieveUi {
-namespace VacationUtils {
+namespace KSieveUi
+{
+namespace VacationUtils
+{
 enum MailAction {
     Keep,
     Discard,
